@@ -8,7 +8,8 @@
 #' @param prob probability of success in each trial. 0 < prob <= 1.
 #' @param mu alternative parametrization via mean.
 #' @param log	logical; if TRUE, probabilities p are given as log(p).
-#' @param infinite Number of maximal iterations; check different values to determine the error in estimation.
+#' @param tol Tolerance for recurrence
+#' @param infinite No more used - Maintained for retrocompatibility
 #' @description Density for the sum of random variable with negative binomial distributions.\cr
 #' If all prob values are the same, infinite is automatically set to 0.
 #' @family Distribution of sum of random variable with negative binomial distributions
@@ -16,16 +17,8 @@
 #' \dontrun{
 #' alpha <- c(1, 2, 5, 1, 2)
 #' p <- c(0.1, 0.12, 0.13, 0.14, 0.14)
-#' # Test with lower iterations: 2 or 50 rather than 10 [default]; precision is very good still with 10
-#' dSnbinom(20, size=alpha, prob=p, infinite=50)
-#' dSnbinom(20, size=alpha, prob=p, infinite=10)
-#' dSnbinom(20, size=alpha, prob=p, infinite=2)
-#' # However it is not always the case; It depends on the parametrization (see Furman 2007)
-#' dSnbinom(20, size=2, mu=c(0.01, 0.02, 0.03), infinite=1000)
-#' dSnbinom(20, size=2, mu=c(0.01, 0.02, 0.03), infinite=100)
-#' dSnbinom(20, size=2, mu=c(0.01, 0.02, 0.03), infinite=50)
-#' dSnbinom(20, size=2, mu=c(0.01, 0.02, 0.03), infinite=10)
-#' dSnbinom(20, size=2, mu=c(0.01, 0.02, 0.03), infinite=2)
+#' dSnbinom(20, size=alpha, prob=p)
+#' dSnbinom(20, size=2, mu=c(0.01, 0.02, 0.03))
 #' # Test with a single distribution
 #' dSnbinom(20, size=1, mu=20)
 #' # when only one distribution is available, it is the same as dnbinom()
@@ -43,14 +36,14 @@
 #' names(tabledistEmpirique) <- as.character(0:300)
 #' tabledistEmpirique[names(table(distEmpirique))] <- table(distEmpirique)/rep
 #' 
-#' plot(0:300, dSnbinom(0:300, size=alpha, mu=mu, infinite=1000), type="h", bty="n", 
+#' plot(0:300, dSnbinom(0:300, size=alpha, mu=mu), type="h", bty="n", 
 #'    xlab="x", ylab="Density", ylim=c(0,0.02))
 #' plot_add(0:300, tabledistEmpirique, type="l", col="red")
 #' legend(x=200, y=0.02, legend=c("Empirical", "Theoretical"), 
 #'    text.col=c("red", "black"), bty="n")
 #' 
 #' # Example with the approximation mu=mean(mu)
-#' plot(0:300, dSnbinom(0:300, size=alpha, mu=mu, infinite=0), type="h", bty="n", 
+#' plot(0:300, dSnbinom(0:300, size=alpha, mu=mu), type="h", bty="n", 
 #'    xlab="x", ylab="Density", ylim=c(0,0.02))
 #' plot_add(0:300, tabledistEmpirique, type="l", col="red")
 #' legend(x=200, y=0.02, legend=c("Empirical", "Theoretical"), 
@@ -66,8 +59,7 @@
 #' parx <- c(size=1, mu=10)
 #' 
 #' dSnbinomx <- function(x, par) {
-#'   -sum(dSnbinom(x=x[,2], mu=rep(par["mu"], 10), size=par["size"], log=TRUE, 
-#'                 infinite = 1000))
+#'   -sum(dSnbinom(x=x[,2], mu=rep(par["mu"], 10), size=par["size"], log=TRUE))
 #' }
 #' 
 #' fit_mu_size <- optim(par = parx, fn=dSnbinomx, x=r, method="BFGS", control=c(trace=TRUE))
@@ -77,8 +69,10 @@
 
 dSnbinom <- function(x=stop("You must provide a x value"), 
                      size=NULL, 
-                     prob=NULL, mu=NULL, log = FALSE, infinite=100) {
+                     prob=NULL, mu=NULL, log = FALSE,  tol=1E-6,
+                     infinite=1000) {
   
+  infinite <- 1000
   # prob=NULL; mu=NULL; log = FALSE; infinite=10
   if (is.null(mu) + is.null(size) + is.null(prob) != 1) stop("Two values among mu, size and prob must be provided")
   
@@ -122,8 +116,14 @@ dSnbinom <- function(x=stop("You must provide a x value"),
       xi[i] <- sum((alpha*(1-((q1*p)/(q*p1)))^i)/i)
       Ks <- 1:i
       delta[i+1] <- (1/i)*sum(Ks*xi[Ks]*delta[i-Ks+1])
+      if (abs((delta[i+1] - delta[i])) < tol) {
+        delta <- delta[!is.na(delta)]
+        break
+      }
     }
     
+    
+    
     Pr <- sapply(x, function(S) {
       PrS <- R*sum(delta*dnbinom(S, size=sum(alpha)+seq_along(delta)-1, prob=p1))
       if (log) PrS <- log(PrS)
